#[non_exhaustive]pub struct TranscriptPiece {
pub id: String,
pub index: u32,
pub count: u32,
pub text: String,
pub estimated_tokens: u64,
}Expand description
One deterministic transcript-only piece.
Fields are readable by consumers, while construction remains owned by
TranscriptPlan.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Stringindex: u32count: u32text: Stringestimated_tokens: u64Implementations
Sourceimpl TranscriptPiece
impl TranscriptPiece
Sourcepub fn metadata(&self, recording: &RecordingStatus) -> Value
pub fn metadata(&self, recording: &RecordingStatus) -> Value
Reproduces the existing audio ingress metadata for this piece.
Sourcepub fn formatted_text(
&self,
recording: &RecordingStatus,
) -> Result<String, Error>
pub fn formatted_text( &self, recording: &RecordingStatus, ) -> Result<String, Error>
Reproduces the existing History input for this piece.