pub struct TranscriptPlan { /* private fields */ }Expand description
The complete deterministic piece plan for one recording status.
Implementations
Sourceimpl TranscriptPlan
impl TranscriptPlan
Sourcepub fn new(
recording: &RecordingStatus,
effective_context_tokens: u64,
) -> Result<Self, Error>
pub fn new( recording: &RecordingStatus, effective_context_tokens: u64, ) -> Result<Self, Error>
Plans a completed transcript using one quarter of the effective context.
A recording that is not complete produces an empty plan.
Sourcepub fn pieces(&self) -> &[TranscriptPiece]
pub fn pieces(&self) -> &[TranscriptPiece]
Returns the ordered, complete piece plan.